@@ -2,8 +2,8 @@ package FBP::StaticText;
 
 use Moose;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
-extends 'FBP::Parent';
+extends 'FBP::Window';
 
 1;
